@@ -1,4 +1,4 @@
-/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Config.c,v 1.23 2006/03/12 00:11:33 krh Exp $ */
+/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Config.c,v 1.23.2.4 2006/04/07 01:37:03 ajax Exp $ */
 /* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Config.c,v 3.276 2003/10/08 14:58:26 dawes Exp $ */
 
 
@@ -666,7 +666,36 @@ configFiles(XF86ConfFilesPtr fileconf)
   if (! *defaultFontPath)
     FatalError("No valid FontPath could be found.");
 
-  xf86Msg(pathFrom, "FontPath set to \"%s\"\n", defaultFontPath);
+  /* make fontpath more readable in the logfiles */
+  int countDirs = 1;
+  char *temp_path = defaultFontPath;
+  while((temp_path = index(temp_path, ',')) != NULL) {
+    countDirs++;
+    temp_path++;
+  }
+  char *log_buf = xnfalloc(strlen(defaultFontPath) + (2 * countDirs) + 1);
+  if(!log_buf) /* fallback to old method */
+    xf86Msg(pathFrom, "FontPath set to \"%s\"\n", defaultFontPath);
+  else {
+    char *start, *end;
+    int size;
+    temp_path = log_buf;
+    start = defaultFontPath;
+    while((end = index(start, ',')) != NULL) {
+      size = (end - start) + 1;
+      *(temp_path++) = '\t';
+      strncpy(temp_path, start, size);
+      temp_path += size;
+      *(temp_path++) = '\n';
+      start += size;
+    }
+    /* copy last entry */
+    *(temp_path++) = '\t';
+    strcpy(temp_path, start);
+    xf86Msg(pathFrom, "FontPath set to:\n%s\n", log_buf);
+    xfree(log_buf);
+  }
+
 
   /* RgbPath */
 
@@ -1791,8 +1820,10 @@ configLayout(serverLayoutPtr servlayoutp, XF86ConfLayoutPtr conf_layout,
 	else
 	    scrnum = adjp->adj_scrnum;
 	if (!configScreen(slp[count].screen, adjp->adj_screen, scrnum,
-			  X_CONFIG))
+			  X_CONFIG)) {
+	    xfree(slp);
 	    return FALSE;
+	}
 	slp[count].x = adjp->adj_x;
 	slp[count].y = adjp->adj_y;
 	slp[count].refname = adjp->adj_refscreen;
@@ -1921,8 +1952,10 @@ configLayout(serverLayoutPtr servlayoutp, XF86ConfLayoutPtr conf_layout,
     idp = conf_layout->lay_inactive_lst;
     count = 0;
     while (idp) {
-	if (!configDevice(&gdp[count], idp->inactive_device, FALSE))
+	if (!configDevice(&gdp[count], idp->inactive_device, FALSE)) {
+	    xfree(gdp);
 	    return FALSE;
+	}
         count++;
         idp = (XF86ConfInactivePtr)idp->list.next;
     }
@@ -1944,8 +1977,10 @@ configLayout(serverLayoutPtr servlayoutp, XF86ConfLayoutPtr conf_layout,
     irp = conf_layout->lay_input_lst;
     count = 0;
     while (irp) {
-	if (!configInput(&indp[count], irp->iref_inputdev, X_CONFIG))
+	if (!configInput(&indp[count], irp->iref_inputdev, X_CONFIG)) {
+	    xfree(indp);
 	    return FALSE;
+	}
 	indp[count].extraOptions = irp->iref_option_lst;
         count++;
         irp = (XF86ConfInputrefPtr)irp->list.next;
@@ -2005,8 +2040,10 @@ configImpliedLayout(serverLayoutPtr servlayoutp, XF86ConfScreenPtr conf_screen)
     slp = xnfcalloc(1, 2 * sizeof(screenLayoutRec));
     slp[0].screen = xnfcalloc(1, sizeof(confScreenRec));
     slp[1].screen = NULL;
-    if (!configScreen(slp[0].screen, conf_screen, 0, from))
+    if (!configScreen(slp[0].screen, conf_screen, 0, from)) {
+	xfree(slp);
 	return FALSE;
+    }
     servlayoutp->id = "(implicit)";
     servlayoutp->screens = slp;
     servlayoutp->inactives = xnfcalloc(1, sizeof(GDevRec));
@@ -2520,6 +2557,7 @@ configExtensions(XF86ConfExtensionsPtr conf_ext)
 		xf86Msg(X_ERROR,
 			"%s is not a valid value for the Extension option\n",
 			val);
+		xfree(n);
 		return FALSE;
 	    }
 
@@ -2530,6 +2568,7 @@ configExtensions(XF86ConfExtensionsPtr conf_ext)
 		xf86Msg(X_WARNING, "Ignoring unrecognized extension \"%s\"\n",
                         name);
 	    }
+	    xfree(n);
 	}
     }
 
