@@ -1589,8 +1589,10 @@ ProcXF86VidModeGetGammaRamp(ClientPtr client)
 	    return BadAlloc;
    
         if (!VidModeGetGammaRamp(stuff->screen, stuff->size, 
-		ramp, ramp + length, ramp + (length * 2)))
+		ramp, ramp + length, ramp + (length * 2))) {
+	    xfree(ramp);
             return BadValue;
+	}
     }
 
     rep.type = X_Reply;
