@@ -1,4 +1,4 @@
-/* $XdotOrg: $ */
+/* $XdotOrg: xserver/xorg/hw/xfree86/utils/xorgcfg/interface.c,v 1.8 2005/11/08 06:33:30 jkj Exp $ */
 /*
  * Copyright (c) 2000 by Conectiva S.A. (http://www.conectiva.com)
  * 
@@ -65,9 +65,12 @@
 #ifdef PROJECT_ROOT
 #define DefaultXFree86Dir	PROJECT_ROOT
 #else
-#define DefaultXFree86Dir	"/usr/X11R6"
+#define DefaultXFree86Dir	"/usr"
 #endif
 
+#define IS_KBDDRIV(S) ((strcasecmp((S),"kbd") == 0) || \
+	(strcasecmp((S), "keyboard") == 0))
+
 /*
  * Prototypes
  */
@@ -791,7 +794,7 @@ InitializeDevices(void)
 		    mouse_x = work->core.width - (work->core.width >> 2);
 		}
 	    }
-	    else if (strcasecmp(input->inp_driver, "keyboard") == 0) {
+	    else if (IS_KBDDRIV(input->inp_driver)) {
 		device = AddDevice(KEYBOARD, (XtPointer)input, keyboard_x, keyboard_y);
 		SetTip(device);
 		if ((keyboard_x += DEFAULT_KEYBOARD_WIDTH) >
@@ -1645,8 +1648,7 @@ EnableDeviceCallback(Widget w, XtPointer user_data, XtPointer call_data)
 	    while (nex != NULL) {
 		if (strcasecmp(nex->iref_inputdev->inp_driver, "mouse") == 0)
 		    ++nmouses;
-		else if (strcasecmp(nex->iref_inputdev->inp_driver,
-				    "keyboard") == 0)
+		else if (IS_KBDDRIV(nex->iref_inputdev->inp_driver))
 		    ++nkeyboards;
 		iref = nex;
 		nex = (XF86ConfInputrefPtr)(nex->list.next);
